@@ -21,14 +21,23 @@
 # it from the source dir without installing.
 
 import sys
-
+import os
 import src
 import src.configureoutput
 
 src.configureoutput.prefix = "."
-
+src.configureoutput.datadir = "."
 import src.cfg
-src.cfg.initialise(None, "default.config", "~/.solfegerc")
+
+import src.gethomedir
+if not os.path.exists(src.gethomedir.get_home_dir()):
+    os.mkdir(src.gethomedir.get_home_dir())
+
+if sys.platform == 'win32':
+    print "Using as home dir:", src.gethomedir.get_home_dir()
+
+src.cfg.initialise(None, "default.config", 
+                   os.path.join(src.gethomedir.get_home_dir(), ".solfegerc"))
 
 import src.mainwin
 
