@@ -1,5 +1,5 @@
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005 Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -53,10 +53,15 @@ class MidiFileSynth:
             raise "Shit"
     def close(self):
         pass
+    def join_cmd_and_filename(self, cmd, filename):
+        if cmd.find("%s") != -1:
+            return cmd % filename
+        else:
+            return " ".join((cmd, filename))
     def _play_track_system(self, track):
         track.prepend_bpm(60)
         self.create_midifile(track)
-        os.system(self.m_cmd % self.m_tmpfilename)
+        os.system(self.join_cmd_and_filename(self.m_cmd, self.m_tmpfilename))
         # spawnl(os.P_DETACH, 'c:\\python20\\python', 'python', 'script.py')
         # #P_DETACH'ed can be killed
     def _play_track_fork_execl(self, track):
@@ -75,7 +80,7 @@ class MidiFileSynth:
             self.__child_pid = None
         pid = os.fork()
         if pid == 0:
-            v = (self.m_cmd % self.m_tmpfilename).split(" ")
+            v = self.join_cmd_and_filename(self.m_cmd, self.m_tmpfilename).split(" ")
             v = v[:1] + [""] + v[1:]
             try:
                 os.execlp(*v)
