@@ -15,7 +15,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import gtk, gnome
+import gtk, gnome, gobject
 import gu
 import inputwidgets
 import widgets
@@ -61,10 +61,10 @@ class Teacher(cfg.ConfigUtils):
                 def remove_timeout(self=self):
                     self.m_timeout_handle = None
                     self.g_view.new_question()
-                self.m_timeout_handle = gtk.timeout_add((self.get_int('seconds_before_new_question')*1000),  remove_timeout)
+                self.m_timeout_handle = gobject.timeout_add((self.get_int('seconds_before_new_question')*1000),  remove_timeout)
     def end_practise(self):
         if self.m_timeout_handle:
-            gtk.timeout_remove(self.m_timeout_handle)
+            gobject.source_remove(self.m_timeout_handle)
             self.m_timeout_handle = None
         self.q_status = const.QSTATUS_NO
         soundcard.synth.stop()
@@ -95,7 +95,7 @@ class MelodicIntervalTeacher(Teacher):
                      self.get_list('ask_for_intervals_0'))
 
         if self.m_timeout_handle:
-            gtk.timeout_remove(self.m_timeout_handle)
+            gobject.source_remove(self.m_timeout_handle)
             self.m_timeout_handle = None
 
         if self.get_bool('config/picky_on_new_question') \
@@ -186,7 +186,7 @@ class LessonbasedTeacher(Teacher):
             self.set_string('lessonfile', lessonfile)
         self.__make_sure_existing_lessonfile_is_selected()
         self.parse_lessonfile()
-        if new_file and self.m_P.header.questions_selectable:
+        if new_file and self.m_P and self.m_P.header.questions_selectable:
             self.block_watch('ask_for_names')
             self.set_list('ask_for_names', range(0, len(self.m_P.get_unique_cnames())))
             self.unblock_watch('ask_for_names')
@@ -221,15 +221,17 @@ class LessonbasedTeacher(Teacher):
 """There was an IOError while trying to parse a lesson file. The cause was probably you deleting or renaming a lesson file. Please don't do this while Solfege is running. The program is still a little fragile. 
 
 You really should reastart the program now.""")
-        if self.m_P.header.musicformat == "cmdline":
-            run = self.m_app.m_ui.dialog_yesno(_("The lessonfile contain potentially dangerous code because the lesson file set the variable \"musicformat\" to \"cmdline\". Run anyway?"))
+        if filter(lambda q: q['music'].m_musictype == 'cmdline',
+                  self.m_P.m_questions):
+            run = self.m_app.m_ui.dialog_yesno(_("The lessonfile contain potentially dangerous code because it run external programs. Run anyway?"))
             if not run:
                 self.m_P = None
     def configure_exercise(self, lessoncollection, lessonfile, config):
-    	"""This function should not be called by the constructors.
-	abstract.Teacher and abstract.LessonbasedTeacher does the same job,
-	but in correct order.
-	"""
+        """
+        This function should not be called by the constructors.
+        abstract.Teacher and abstract.LessonbasedTeacher does the same job,
+        but in correct order.
+        """
         if lessoncollection or lessonfile:
             if lessoncollection:
                 self.set_string('lessoncollection', lessoncollection)
@@ -248,7 +250,6 @@ class Gui(gtk.VBox, cfg.ConfigUtils):
     def __init__(self, teacher, window, no_notebook=0):
         gtk.VBox.__init__(self)
         cfg.ConfigUtils.__init__(self, teacher.m_exname)
-        #cfg.ConfigUtils.__dict__['__init__'](self, teacher.m_exname)
         self.m_key_bindings = {}
         self.m_t = teacher
         self.g_win = window
@@ -260,11 +261,11 @@ class Gui(gtk.VBox, cfg.ConfigUtils):
 
         self.practise_box = gtk.VBox()
         self.practise_box.show()
-        vbox.pack_start(self.practise_box)
+        vbox.pack_start(self.practise_box, False)
 
         self.action_area = gtk.HBox()
         self.action_area.show()
-        vbox.pack_end(self.action_area, False)
+        vbox.pack_start(self.action_area, False)
 
         self.config_box = gtk.VBox()
         self.config_box.set_border_width(gnome.ui.PAD)
