@@ -16,11 +16,12 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import gtk
+import gobject
 
 __exercise_data__ = {
     'exercise_name': 'chord-voicing',
     'menu_path': '%s/%s' % (_("_Chords"), _("_Chord voicing")),
-    'icon': 'graphics/chord24.png',
+    'stock-icon': 'solfege-chord-voicing',
     'toolbar': 1,
 }
 import exercise_setup
@@ -346,7 +347,7 @@ class Gui(abstract.LessonbasedGui):
             c.set_sensitive(c.get_data('chordtype')==t)
     def on_start_practise(self):
         self.g_new.grab_focus()
-        gtk.timeout_add(const.SHORT_WAIT, lambda self=self:
+        gobject.timeout_add(const.SHORT_WAIT, lambda self=self:
             self.g_flashbar.flash(_("Click 'New chord' to begin.")))
         self.fill_chordtype_box()
         self.clear_stacking_frame()
