@@ -320,17 +320,6 @@ class ConfigWindow(gnome.ui.PropertyBox, cfg.ConfigUtils):
         page_vbox.pack_start(box, False)
 
         sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
-        self.g_wav_player = gtk.Combo()
-        self.g_wav_player.set_popdown_strings(('/usr/bin/aplay',
-                                               '/usr/bin/play'))
-        self.g_wav_player.entry.set_text(cfg.get_string('sound/wav_player'))
-        self.g_wav_player.entry.connect('changed', self.on_changed)
-        button = gtk.Button(_("Test"))
-        button.connect('clicked', self.test_wav_player)
-        box = gu.hig_label_widget(".wav file player",
-                                  [self.g_wav_player, button],
-                                  sizegroup)
-        category_vbox.pack_start(box)
 
         self.g_midi_player = gtk.Combo()
         self.g_midi_player.set_popdown_strings(('/usr/bin/timidity -idqq %s',
@@ -346,7 +335,7 @@ class ConfigWindow(gnome.ui.PropertyBox, cfg.ConfigUtils):
 
         box, category_vbox = gu.hig_category_vbox(_("Sound setup"))
         page_vbox.pack_start(box)
-        txt = gtk.Label(_("""Solfege has two ways to play music. It is recommended to use Windows multimedia output. An external midiplayer is only useful if your soundcard lack a hardware synth, and you have to use a program like timidity to play the music."""))
+        txt = gtk.Label(_("""Solfege has two ways to play midi files. It is recommended to use Windows multimedia output. An external midiplayer can be useful if your soundcard lack a hardware synth, and you have to use a program like timidity to play the music."""))
         txt.set_line_wrap(1)
         txt.set_justify(gtk.JUSTIFY_FILL)
         txt.set_alignment(0.0, 0.0)
@@ -379,12 +368,12 @@ class ConfigWindow(gnome.ui.PropertyBox, cfg.ConfigUtils):
         self.g_midiplayer_radio.connect('clicked', self.on_changed)
         self.g_synth_num.connect('changed', self.on_changed)
         self.g_device_radio.connect('clicked', self.on_changed)
-    def test_wav_player(self, w):
-        app.run_external_program(self.g_wav_player.entry.get_text(),
-                 'lesson-files/share', 'fifth-small-220.00.wav')
     def test_midi_player(self, w):
         app.run_external_program(self.g_midi_player.entry.get_text(),
                         'lesson-files/share', 'fanfare.midi')
+    def test_wav_player(self, w):
+        app.run_external_program(self.g_wav_player.entry.get_text(),
+                        'lesson-files/share', 'fifth-small-220.00.wav')
     def on_sound_test(self, w):
         mpd.play_music(r"""
         \staff\relative c{
@@ -506,8 +495,6 @@ class ConfigWindow(gnome.ui.PropertyBox, cfg.ConfigUtils):
                 # we set the spin just in case m_devnum was changed by the
                 # soundcard setup code, if it was out of range
                 self.g_synth_num.set_value(soundcard.synth.m_devnum)
-            self.set_string("sound/wav_player",
-                            self.g_wav_player.entry.get_text())
             self.set_string("sound/midi_player",
                             self.g_midi_player.entry.get_text())
         if pagenum == -1:
