@@ -1,5 +1,5 @@
 # GNU Solfege - ear training for GNOME
-# Copyright (C) 2000, 2001, 2002, 2003, 2004  Tom Cato Amundsen
+# Copyright (C) 2000, 2001, 2002, 2003, 2004, 2005 Tom Cato Amundsen
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 __exercise_data__ = {
     'exercise_name': 'id-by-name',
     'menu_path': '%s/%s' % (_("_Misc exercises"), _("Id_entify by name")),
-    'icon': 'graphics/idbyname24.png',
+    'stock-icon': 'solfege-id-by-name',
     'toolbar': 5,
 }
 import exercise_setup
@@ -31,7 +31,7 @@ if __name__ == 'idbyname':
     import i18n
     i18n.setup_srcdir()
 
-import gtk, gnome
+import gtk, gnome, gobject
 import gu, widgets
 import abstract, const, mpd, mpd.musicdisplayer
 import utils
@@ -62,7 +62,7 @@ class Teacher(abstract.LessonbasedTeacher):
         UI will never call this function unless we have a usable lessonfile.
         """
         if self.m_timeout_handle:
-            gtk.timeout_remove(self.m_timeout_handle)
+            gobject.source_remove(self.m_timeout_handle)
             self.m_timeout_handle = None
 
         if self.get_bool('config/picky_on_new_question') \
@@ -165,6 +165,8 @@ class Gui(abstract.LessonbasedGui):
                       self.m_t.m_P.header.labelformat, self.on_click)
         else:
             self.g_bb.initialize(0, 0)
+        if self.m_t.m_P and self.m_t.m_P.header.questions_selectable:
+            self.g_bb.ask_for_names_changed()
     def update_select_question_buttons(self):
         if self.m_t.m_P and self.m_t.m_P.header.questions_selectable:
             self.g_select_questions_category_box.show()
@@ -182,13 +184,12 @@ class Gui(abstract.LessonbasedGui):
         self.g_repeat_arpeggio.set_sensitive(False)
         self.g_show.set_sensitive(False)
         self.g_give_up.set_sensitive(False)
-        self.update_answer_buttons()
-        self.update_select_question_buttons()
         self.g_win.set_title("Solfege - " + self.get_pretty_name())
         if self.m_t.m_P:
             self.g_new.set_sensitive(True)
             self.g_random_transpose.set_text(str(self.m_t.m_P.header.random_transpose))
-            if self.m_t.m_P.header.musicformat == 'chord':
+            if filter(lambda q: q['music'].m_musictype == 'chord',
+                      self.m_t.m_P.m_questions):
                 self.g_repeat_arpeggio.show()
             else:
                 self.g_repeat_arpeggio.hide()
@@ -219,6 +220,8 @@ class Gui(abstract.LessonbasedGui):
                             question['active'] = 1
         else:
             self.g_new.set_sensitive(False)
+        self.update_select_question_buttons()
+        self.update_answer_buttons()
     def give_up(self, _o=None):
         if self.m_t.q_status == const.QSTATUS_WRONG:
             self.g_flashbar.push(_("The answer is: %s") % self.m_t.m_P.get_name())
@@ -332,7 +335,7 @@ class Gui(abstract.LessonbasedGui):
         self.g_new.grab_focus()
         self.m_t.m_statistics.reset_session()
         self.g_music_displayer.clear()
-        gtk.timeout_add(const.SHORT_WAIT, lambda self=self:
+        gobject.timeout_add(const.SHORT_WAIT, lambda self=self:
             self.g_flashbar.flash(_("Click 'New' to begin.")))
     def on_end_practise(self):
         self.m_t.end_practise()
