@@ -18,13 +18,13 @@
 __exercise_data__ = {
     'exercise_name': 'identify-bpm',
     'menu_path': '%s/%s' % (_("_Rhythm"), _("Bpm")),
-    'icon': 'graphics/identify-bpm24.png',
+    'stock-icon': 'solfege-identify-bpm',
     'toolbar': 12,
 }
 import exercise_setup
 exercise_setup.register_exercise(__exercise_data__)
 
-import gnome, gtk
+import gnome, gtk, gobject
 import soundcard
 import abstract, const, statistics, statisticsviewer, gu, random
 
@@ -79,11 +79,11 @@ class Teacher(abstract.Teacher):
     def start_question(self, bpm):
         self.tick()
         if self.m_timeout_tag:
-            gtk.timeout_remove(self.m_timeout_tag)
-        self.m_timeout_tag = gtk.timeout_add(60000/bpm, self.tick)
+            gobject.source_remove(self.m_timeout_tag)
+        self.m_timeout_tag = gobject.timeout_add(60000/bpm, self.tick)
     def stop_question(self):
         if self.m_timeout_tag:
-            gtk.timeout_remove(self.m_timeout_tag)
+            gobject.source_remove(self.m_timeout_tag)
             self.m_timeout_tag = None
     def tick(self, _o=None):
         soundcard.play_note(0, 8, 9, 60, 90)
