@@ -18,13 +18,14 @@
 __exercise_data__ = {
     'exercise_name': 'id-tone',
     'menu_path': '%s/%s' % (_("_Misc exercises"), _("Id_entify tone")),
-    'icon': 'graphics/idtone24.png',
+    'stock-icon': 'solfege-id-tone',
     'toolbar': 8,
 }
 import exercise_setup
 exercise_setup.register_exercise(__exercise_data__)
 
 import inputwidgets, abstract, const, random, soundcard, gu, mpd, gnome
+import gobject
 import configureoutput
 import gtk
 import gu
@@ -51,7 +52,7 @@ class Teacher(abstract.Teacher):
         ERR_CONFIG: fail, all notes have zero weight or no octaves selected
         """
         if self.m_timeout_handle:
-            gtk.timeout_remove(self.m_timeout_handle)
+            gobject.source_remove(self.m_timeout_handle)
             self.m_timeout_handle = None
 
         if self.get_bool('config/picky_on_new_question') \
@@ -109,7 +110,7 @@ class Gui(abstract.Gui):
         abstract.Gui.__init__(self, teacher, window)
         if not configureoutput.WITH_GNOME:
             self.practise_box.add(gtk.Label(_(
-"""This exercise don't work without GNOME.
+"""This exercise doesn't work without GNOME.
 It can pretty easy be converted to use Pixmap instead
 of GnomeCanvas, but I (tca) don't have time to do this
 right now. But I can answer questions if needed.""")))
@@ -192,7 +193,7 @@ right now. But I can answer questions if needed.""")))
         # statistics #
         ##############
         self.setup_statisticsviewer(statisticsviewer.StatisticsViewer,
-                                   _("idtone"))
+                                   _("Identify tone"))
     def new_question(self, widget=None):
         s = self.m_t.q_status
         g = self.m_t.new_question()
@@ -258,7 +259,7 @@ _("""You have to select some tones practise. Do this on the config page by setti
             return # this exercise don't work without GnomeCanvas
         self.m_t.m_statistics.reset_session()
         self.set_percentage_label()
-        gtk.timeout_add(const.SHORT_WAIT, lambda self=self:
+        gobject.timeout_add(const.SHORT_WAIT, lambda self=self:
             self.g_flashbar.flash(_("Click 'New tone' to begin.")))
         self.g_new_tone.set_sensitive(True)
         self.g_new_tone.grab_focus()
