@@ -1,9 +1,25 @@
+# GNU Solfege - ear training for GNOME
+# Copyright (C) 2004, 2005  Tom Cato Amundsen
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
 from __future__ import division
 
 import pygtk
 pygtk.require("2.0")
 import gtk
-
 import i18n
 i18n.setup()
 
@@ -18,12 +34,20 @@ import dataparser
 import htmlwidget
 import stock
 
-app_version = "0.1.2"
+gtk.stock_add([('solfege-notehead', _("Add noteheads"), 0, 0, ''),
+               ('solfege-sharp', _("Add sharp"), 0, 0, ''),
+               ('solfege-double-sharp', _("Add double-sharp"), 0, 0, ''),
+               ('solfege-natural', _("Remove accidentals"), 0, 0, ''),
+               ('solfege-flat', _("Add flat"), 0, 0, ''),
+               ('solfege-double-flat', _("Add double-flat"), 0, 0, ''),
+               ('solfege-erase', _("Delete tone"), 0, 0, ''),
+               ])
+app_version = "0.1.3"
 
 class HelpWindow(gtk.Window):
     def __init__(self, parent):
         gtk.Window.__init__(self)
-        self.set_title("GNU Solfege lesson file editor help")
+        self.set_title(_("GNU Solfege lesson file editor") )
         self.set_default_size(400, 400)
         self.g_parent = parent
         self.vbox = gtk.VBox()
@@ -51,29 +75,41 @@ class HelpWindow(gtk.Window):
 
 
 window_actions = [
-    ('FileMenu', None, '_File'),
-    ('NewLessonfile', gtk.STOCK_NEW, '_New', '<control>N', 'new file', 'file_new_cb'),
-    ('Open', gtk.STOCK_OPEN, '_Open', '<control>O', 'Open lesson file', 'file_open_cb'),
-    ('Save', gtk.STOCK_SAVE, '_Save', '<control>S', 'Save the lesson file', 'file_save_cb'),
-    ('SaveAs', gtk.STOCK_SAVE_AS, 'Save _as', '', 'Save the lesson file with a new name', 'file_save_as_cb'),
-    ('Quit', gtk.STOCK_QUIT, '_Quit', '<control>Q', 'Quit program', 'quit_cb'),
-    ('HelpMenu', None, '_Help'),
-    ('HelpHelp', gtk.STOCK_HELP, '_Help', '', '', 'help_cb'),
-    ('HelpAbout', None, '_About', '', '', 'about_cb'),
+    ('FileMenu', None, _('_File')),
+    ('NewLessonfile', gtk.STOCK_NEW, None, None, 'new file', 'file_new_cb'),
+    ('Open', gtk.STOCK_OPEN, None, None, 'Open lesson file', 'file_open_cb'),
+    ('Save', gtk.STOCK_SAVE, None, None, 'Save the lesson file', 'file_save_cb'),
+    ('SaveAs', gtk.STOCK_SAVE_AS, None, None, 'Save the lesson file with a new name', 'file_save_as_cb'),
+    ('Quit', gtk.STOCK_QUIT, None, None, 'Quit program', 'quit_cb'),
+    ('HelpMenu', None, _('_Help')),
+    ('HelpHelp', gtk.STOCK_HELP, None, None, None, 'help_cb'),
+    ('HelpAbout', None, _('_About'), '', '', 'about_cb'),
 ]
 lessonfile_actions = [
-    ('GotoFirstQuestion', gtk.STOCK_GOTO_FIRST, '_Goto first', '<control>i', 'Go to the first question', 'goto_first_question_cb'),
-    ('GoBackQuestion', gtk.STOCK_GO_BACK, '_Goto back', '<control>b', 'Go to the previous question', 'go_back_question_cb'),
-    ('GoForwardQuestion', gtk.STOCK_GO_FORWARD, '_Goto forward', '<control>f', 'Go to the next question', 'go_forward_question_cb'),
-    ('GotoLastQuestion', gtk.STOCK_GOTO_LAST, '_Goto last', '<control>a', 'Go to the last question', 'goto_last_question_cb'),
-    ('NewQuestion', gtk.STOCK_ADD, '_New question', '<control>n', 'Add a new question', 'new_question_cb'),
-    ('NoteheadCursor', stock.NOTEHEAD, 'Add noteheads', '', 'Select tool to add notehead', 'select_cursor_notehead_cb'),
-    ('SharpCursor', stock.SHARP, 'Add accidental to tone', '', 'Select tool to add sharps to tones', 'select_cursor_sharp_cb'),
-    ('DoubleSharpCursor', stock.DOUBLE_SHARP, 'Add accidental to tone', '', 'Select tool to add double-sharps to tones', 'select_cursor_2sharp_cb'),
-    ('NaturalCursor', stock.NATURAL, 'Add accidental to tone', '', 'Select tool to remove any accidental from tones', 'select_cursor_natural_cb'),
-    ('FlatCursor', stock.FLAT, 'Add accidental to tone', '', 'Select tool to add flats to tones', 'select_cursor_flat_cb'),
-    ('DoubleFlatCursor', stock.DOUBLE_FLAT, 'Add accidental to tone', '', 'Select tool to add double-flats to tones', 'select_cursor_2flat_cb'),
-    ('EraseCursor', stock.ERASE_TOOL, 'Delete', '', 'Select tool to erase tones', 'select_cursor_erase_cb'),
+    ('GotoFirstQuestion', gtk.STOCK_GOTO_FIRST, None, None,
+     _('Go to the first question'), 'goto_first_question_cb'),
+    ('GoBackQuestion', gtk.STOCK_GO_BACK, None, None,
+     _('Go to the previous question'), 'go_back_question_cb'),
+    ('GoForwardQuestion', gtk.STOCK_GO_FORWARD, None, None,
+     _('Go to the next question'), 'go_forward_question_cb'),
+    ('GotoLastQuestion', gtk.STOCK_GOTO_LAST, None, None,
+     _('Go to the last question'), 'goto_last_question_cb'),
+    ('NewQuestion', gtk.STOCK_ADD, None, None,
+     _('Add a new question'), 'new_question_cb'),
+    ('NoteheadCursor', 'solfege-notehead', None, None,
+     _('Select tool to add noteheads'), 'select_cursor_notehead_cb'),
+    ('SharpCursor', 'solfege-sharp', None, None,
+     _('Select tool to add sharps to tones'), 'select_cursor_sharp_cb'),
+    ('DoubleSharpCursor', 'solfege-double-sharp', None, None,
+     _('Select tool to add double-sharps to tones'), 'select_cursor_2sharp_cb'),
+    ('NaturalCursor', 'solfege-natural', None, None,
+     _('Select tool to remove any accidental from tones'), 'select_cursor_natural_cb'),
+    ('FlatCursor', 'solfege-flat', None, None,
+     _('Select tool to add flats to tones'), 'select_cursor_flat_cb'),
+    ('DoubleFlatCursor', 'solfege-double-flat', None, None,
+     _('Select tool to add double-flats to tones'), 'select_cursor_2flat_cb'),
+    ('EraseCursor', 'solfege-erase', None, None,
+     _('Select tool to erase tones'), 'select_cursor_erase_cb'),
 ]
 ui_string = """<ui>
   <menubar name='Menubar'>
@@ -106,17 +142,16 @@ ui_string = """<ui>
     <toolitem action='EraseCursor'/>
   </toolbar>
 </ui>"""
+
 def fix_actions(actions, instance):
     "Helper function to map methods to an instance"
     retval = []
-    
     for i in range(len(actions)):
         curr = actions[i]
         if len(curr) > 5:
             curr = list(curr)
             curr[5] = getattr(instance, curr[5])
             curr = tuple(curr)
-            
         retval.append(curr)
     return retval
 
@@ -134,7 +169,7 @@ class EditorLessonfile(object):
 class MainWin(gtk.Window):
     def __init__(self, datadir):
         gtk.Window.__init__(self)
-        self.icons = stock.IconFactory(self, datadir)
+        self.icons = stock.EditorIconFactory(self, datadir)
         self.connect('destroy', lambda w: gtk.main_quit())
         self.g_help_window = None
         # toplevel_vbox:
@@ -154,7 +189,7 @@ class MainWin(gtk.Window):
     def create_mainwin_ui(self):
         qbox = gu.hig_dlg_vbox()
         self.g_notebook.append_page(qbox, gtk.Label(_("Questions")))
-        gu.bLabel(qbox, "Enter new chord using the mouse", False, False)
+        gu.bLabel(qbox, _("Enter new chords using the mouse"), False, False)
         hbox = gu.bHBox(qbox, False, False)
         self.g_displayer = mpd.musicdisplayer.ChordEditor()
         self.g_displayer.connect('clicked', self.on_displayer_clicked)
@@ -164,7 +199,7 @@ class MainWin(gtk.Window):
         gu.bLabel(hbox, "")
         ##
         self.g_question_name = gtk.Entry()
-        qbox.pack_start(gu.hig_label_widget("Question title:", self.g_question_name, None), False)
+        qbox.pack_start(gu.hig_label_widget(_("Question title:"), self.g_question_name, None), False)
         self.g_navinfo = gtk.Label("")
         qbox.pack_start(self.g_navinfo, False)
 
@@ -175,7 +210,7 @@ class MainWin(gtk.Window):
         ## Header section
         sizegroup = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
         self.g_title = gtk.Entry()
-        cvbox.pack_start(gu.hig_label_widget("File title:", self.g_title, 
+        cvbox.pack_start(gu.hig_label_widget(_("File title:"), self.g_title, 
                         sizegroup))
         self.g_content_chord = gtk.CheckButton("chord")
         self.g_content_chord_voicing = gtk.CheckButton("chord-voicing")
@@ -184,9 +219,9 @@ class MainWin(gtk.Window):
         box.pack_start(self.g_content_chord)
         box.pack_start(self.g_content_chord_voicing)
         box.pack_start(self.g_content_idbyname)
-        cvbox.pack_start(gu.hig_label_widget("Content:", box, sizegroup))
+        cvbox.pack_start(gu.hig_label_widget(_("Content:"), box, sizegroup))
         self.g_random_transpose = gtk.Entry()
-        cvbox.pack_start(gu.hig_label_widget("Random transpose:", 
+        cvbox.pack_start(gu.hig_label_widget(_("Random transpose:"), 
             self.g_random_transpose, sizegroup))
         #
         #self.g_statusbar = gtk.Statusbar()
@@ -196,7 +231,7 @@ class MainWin(gtk.Window):
         if not self.m_P.m_changed:
             return True
         dialog = gtk.MessageDialog(self, gtk.DIALOG_MODAL, gtk.MESSAGE_QUESTION,
-              gtk.BUTTONS_YES_NO, "You have unsaved data. Proceed anyway?")
+              gtk.BUTTONS_YES_NO, _("You have unsaved data. Proceed anyway?"))
         dialog.hide()
         if dialog.run() == gtk.RESPONSE_YES:
             dialog.destroy()
@@ -215,8 +250,8 @@ class MainWin(gtk.Window):
         if self.m_P.m_filename:
             self.set_title(self.m_P.m_filename)
         else:
-            self.set_title("No file")
-        self.g_navinfo.set_text("question %i of %i" % (self.m_P._idx + 1,
+            self.set_title(_("No file"))
+        self.g_navinfo.set_text(_("question %i of %i") % (self.m_P._idx + 1,
                 len(self.m_P.m_questions)))
         self.g_question_name.set_text(self.m_P.m_questions[self.m_P._idx]['name'])
     def load_file(self, filename):
@@ -236,7 +271,7 @@ class MainWin(gtk.Window):
             if c not in ('id-by-name', 'chord', 'chord-voicing'):
                 dialog = gtk.MessageDialog(self, gtk.DIALOG_MODAL,
                     gtk.MESSAGE_ERROR, gtk.BUTTONS_CLOSE,
-                    "Lesson file content '%s' is not supported yet. Cannot edit this file." % c)
+                    _("Lesson file content '%s' is not supported yet. Cannot edit this file.") % c)
                 dialog.run()
                 dialog.destroy()
                 self.m_P = EditorLessonfile()
@@ -246,13 +281,13 @@ class MainWin(gtk.Window):
         if gtk_api == "2.0":
             dialog = gtk.FileSelection()
         else:
-            dialog = gtk.FileChooserDialog("Open..", self,
+            dialog = gtk.FileChooserDialog(_("Open.."), self,
                                        gtk.FILE_CHOOSER_ACTION_OPEN,
                                        (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
                                         gtk.STOCK_OPEN, gtk.RESPONSE_OK))
             dialog.set_default_response(gtk.RESPONSE_OK)
             filter = gtk.FileFilter()
-            filter.set_name("All files")
+            filter.set_name(_("All files"))
             filter.add_pattern("*")
             dialog.add_filter(filter)
         dialog.hide()
@@ -262,8 +297,9 @@ class MainWin(gtk.Window):
                 self.load_file(filename)
             except Exception, e:
                 dialog.destroy()
-                m = gtk.MessageDialog(self, gtk.DIALOG_MODAL, gtk.MESSAGE_ERROR, gtk.BUTTONS_CLOSE,
-                                      "Loading file '%s' failed: %s" % (filename, e))
+                m = gtk.MessageDialog(self, gtk.DIALOG_MODAL, gtk.MESSAGE_ERROR,
+                        gtk.BUTTONS_CLOSE,
+                        _("Loading file '%s' failed: %s") % (filename, e))
                 m.run()
                 m.destroy()
             else:
@@ -279,13 +315,13 @@ class MainWin(gtk.Window):
         if gtk_api == "2.0":
             dialog = gtk.FileSelection()
         else:
-            dialog = gtk.FileChooserDialog("Save as...", self,
+            dialog = gtk.FileChooserDialog(_("Save as..."), self,
                                       gtk.FILE_CHOOSER_ACTION_SAVE,
                                        (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
                                         gtk.STOCK_SAVE, gtk.RESPONSE_OK))
             dialog.set_default_response(gtk.RESPONSE_OK)
             filter = gtk.FileFilter()
-            filter.set_name("All files")
+            filter.set_name(_("All files"))
             filter.add_pattern("*")
             dialog.add_filter(filter)
         dialog.hide()
@@ -300,13 +336,13 @@ class MainWin(gtk.Window):
             if gtk_api == "2.0":
                 dialog = gtk.FileSelection()
             else:
-                dialog = gtk.FileChooserDialog("Save...", self,
+                dialog = gtk.FileChooserDialog(_("Save..."), self,
                                        gtk.FILE_CHOOSER_ACTION_SAVE,
                                        (gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL,
                                         gtk.STOCK_SAVE, gtk.RESPONSE_OK))
                 dialog.set_default_response(gtk.RESPONSE_OK)
                 filter = gtk.FileFilter()
-                filter.set_name("All files")
+                filter.set_name(_("All files"))
                 filter.add_pattern("*")
                 dialog.add_filter(filter)
             dialog.hide()
@@ -357,10 +393,10 @@ edit your hand written lesson files with this program.</p>
 """ % app_version)
             self.g_help_window.show()
         else:
-            print "nothing", self.g_help_window
+            self.g_help_window.present()
     def about_cb(self, *v):
         dialog = gtk.MessageDialog(self, gtk.DIALOG_MODAL, gtk.MESSAGE_INFO,
-            gtk.BUTTONS_CLOSE, "GNU Solfege lesson file editor %s\nCopyright (C) 2004 Tom Cato Amundsen <tca@gnu.org>" % app_version)
+            gtk.BUTTONS_CLOSE, "GNU Solfege lesson file editor %s\nCopyright (C) 2004, 2005 Tom Cato Amundsen <tca@gnu.org>" % app_version)
         dialog.run()
         dialog.destroy()
     def goto_first_question_cb(self, *v):
@@ -418,7 +454,7 @@ edit your hand written lesson files with this program.</p>
             self.g_displayer.display("\staff{ < %s >}\staff{\clef bass}" % s, "20-tight")
         else:
             self.g_displayer.display("\staff{ }\staff{\clef bass}", "20-tight")
-        self.g_displayer.set_size_request(200, -1)
+        self.g_displayer.set_size_request(400, -1)
     def store_data_from_ui(self):
         self.m_P.m_questions[self.m_P._idx]['name'] = self.g_question_name.get_text()
         self.m_P.header.title = self.g_title.get_text()
@@ -452,70 +488,6 @@ edit your hand written lesson files with this program.</p>
         self.m_P.m_questions[self.m_P._idx]['music'].m_musicdata = " ".join(v)
         self.update_score()
 
-class ItemFactoryMainWin(MainWin):
-    def __init__(self, datadir):
-        MainWin.__init__(self, datadir)
-    def create_menu_and_toolbar(self):
-        ag = gtk.AccelGroup()
-        self.add_accel_group(ag)
-        menubar = gtk.MenuBar()
-        i = gtk.MenuItem(_("_File"))
-        menubar.append(i)
-        menu = gtk.Menu()
-        i.set_submenu(menu)
-        i = gu.create_stock_menu_item("gtk-new", _("_New"), self.file_new_cb, ag, gtk.keysyms.N, gtk.gdk.CONTROL_MASK)
-        menu.append(i)
-        i = gu.create_stock_menu_item("gtk-open", _("_Open"), self.file_open_cb, ag, gtk.keysyms.O, gtk.gdk.CONTROL_MASK)
-        menu.append(i)
-        i = gu.create_stock_menu_item("gtk-save", _("_Save"), self.file_save_cb, ag, gtk.keysyms.S, gtk.gdk.CONTROL_MASK)
-        menu.append(i)
-        i = gu.create_stock_menu_item("gtk-save-as", _("Save _as"), self.file_save_as_cb, ag, 0, 0)
-        menu.append(i)
-        i = gtk.SeparatorMenuItem()
-        menu.append(i)
-        i = gu.create_stock_menu_item("gtk-quit", _("_Quit"), self.quit_cb, ag, gtk.keysyms.Q, gtk.gdk.CONTROL_MASK)
-        menu.append(i)
-        ##
-        i = gtk.MenuItem(_("_Help"))
-        menubar.append(i)
-        menu = gtk.Menu()
-        i.set_submenu(menu)
-        i = gu.create_stock_menu_item("gtk-help", _("_Help"), self.help_cb, ag, 0, 0)
-        menu.append(i)
-        i = gu.create_stock_menu_item("gtk-about", _("_About"), self.about_cb, ag, 0, 0)
-        menu.append(i)
-        self.toplevel_vbox.pack_start(menubar, False)
-        ##
-        self.g_toolbar = gtk.Toolbar()
-        self.g_toolbar.set_style(gtk.TOOLBAR_ICONS)
-        self.g_toolbar.insert_stock('gtk-goto-first', 'Go to the first question', None, self.goto_first_question_cb, 0, 2)
-        self.g_toolbar.insert_stock('gtk-go-back', 'Go to the previous question', None, self.go_back_question_cb, 0, 3)
-        self.g_toolbar.insert_stock('gtk-go-forward', 'Go to the next question', None, self.go_forward_question_cb, 0, 4)
-        self.g_toolbar.insert_stock('gtk-goto-last', 'Go to the last question', None, self.goto_last_question_cb, 0, 5)
-        self.g_toolbar.insert_stock('gtk-add', 'Add a new question', None, self.new_question_cb, 0, 6)
-        self.g_toolbar.append_item('', 'Select tool to add notehead', '',
-            gtk.image_new_from_stock(stock.NOTEHEAD, gtk.ICON_SIZE_SMALL_TOOLBAR),
-            self.select_cursor_notehead_cb, None)
-        self.g_toolbar.append_item('', 'Select tool to add sharps to tones', '',
-            gtk.image_new_from_stock(stock.SHARP, gtk.ICON_SIZE_SMALL_TOOLBAR),
-            self.select_cursor_sharp_cb, None)
-        self.g_toolbar.append_item('', 'Select tool to add double-sharps to tones', '',
-            gtk.image_new_from_stock(stock.DOUBLE_SHARP, gtk.ICON_SIZE_SMALL_TOOLBAR),
-            self.select_cursor_2sharp_cb, None)
-        self.g_toolbar.append_item('', 'Select tool to remove any accidentals from tones',
-            '', gtk.image_new_from_stock(stock.NATURAL, gtk.ICON_SIZE_SMALL_TOOLBAR),
-            self.select_cursor_natural_cb, None)
-        self.g_toolbar.append_item('', 'Select tool to add flats to tones', '', 
-            gtk.image_new_from_stock(stock.FLAT, gtk.ICON_SIZE_SMALL_TOOLBAR),
-            self.select_cursor_flat_cb, None)
-        self.g_toolbar.append_item('', 'Select tool to add double-flats to tones', '',
-            gtk.image_new_from_stock(stock.DOUBLE_FLAT, gtk.ICON_SIZE_SMALL_TOOLBAR),
-            self.select_cursor_2flat_cb, None)
-        self.g_toolbar.append_item('', 'Select tol to erase tones', '',
-            gtk.image_new_from_stock(stock.ERASE_TOOL, gtk.ICON_SIZE_SMALL_TOOLBAR),
-            self.select_cursor_erase_cb, None)
-        self.toplevel_vbox.pack_start(self.g_toolbar, False)
-
 class UIManagerMainWin(MainWin):
     def __init__(self, datadir):
         MainWin.__init__(self, datadir)
