@@ -16,14 +16,21 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 import __builtin__
+import types
+try:
+    basestring
+except:
+    basestring = (types.StringType, types.UnicodeType)
+    __builtin__.basestring = basestring
+
 __builtin__.app_running = True
 __builtin__.__exdata__ = []
 
 import sys, os, time, random
 
-if sys.version_info < (2, 3):
+if sys.version_info < (2, 2):
     print "********************************************************************"
-    print "Solfege need Python 2.3 or newer. The configure script told you so!"
+    print "Solfege need Python 2.2 or newer. The configure script told you so!"
     print "********************************************************************"
     sys.exit(-1)
 
@@ -639,10 +646,7 @@ class MainWin(gnome.ui.App, cfg.ConfigUtils):
         for e in __exdata__:
             exdict[e['exercise_name']] = e
             if 'toolbar' in e:
-                if isinstance(e['toolbar'], bool) and e['toolbar'] == True:
-                    tblist_unordered.append(e)
-                else:
-                    tblist_ordered.append(e)
+                tblist_ordered.append(e)
         tblist_ordered.sort(lambda a, b: cmp(a['toolbar'], b['toolbar']))
         for ex in tblist_ordered + tblist_unordered:
             im = gtk.Image()
