@@ -172,7 +172,7 @@ class MultipleIntervalConfigWidget(gtk.VBox, cfg.ConfigUtils):
         """
         if self._watched_interval == i:
             return
-        if self._watched_interval != None:
+        if self._watched_interval is not None:
             self.remove_watch('ask_for_intervals_%i' % self._watched_interval,
                           self._watched_interval_id)
         self._watched_interval = i
