@@ -129,7 +129,7 @@ class SelectLessonfileWidget(gtk.VBox):
         if s:
             self.g_lessonfile_description.source("<html><body bgcolor=white>%s</body></html>" % s)
         else:
-           self.g_lessonfile_description.source("<html></html>")
+            self.g_lessonfile_description.source("<html></html>")
     def toggle_lessonfile_details(self, widget=None):
         self.description_visible = not self.description_visible
         if self.description_visible:
@@ -177,7 +177,7 @@ class FileSelectDialog(gtk.Dialog):
         category_content_vbox.pack_start(hbox, False)
         first_btn = None
         self.m_selected_lessons = {}
-        for coll in cfg.get_string('config/lessoncollections').split():
+        for coll in cfg.get_list('config/lessoncollections'):
             self.m_selected_lessons[coll] = None
             b = gtk.RadioButton(first_btn, coll)
             if self.m_collection == coll:
@@ -219,7 +219,7 @@ class FileSelectDialog(gtk.Dialog):
         self.action_area.get_children()[0].set_sensitive(self.m_can_ok)
     def create_liststore_dict(self):
         self.m_liststore_dict ={}
-        for collection in cfg.get_string('config/lessoncollections').split():
+        for collection in cfg.get_list('config/lessoncollections'):
             self.m_liststore_dict[collection] = \
                  gtk.ListStore(gobject.TYPE_STRING, gobject.TYPE_STRING)
             for d in self.m_lessonfile_manager.get_info(collection, self.m_exname):
