@@ -122,6 +122,10 @@ class Gui(abstract.LessonbasedGui):
                 self.g_repeat_arpeggio.show()
             else:
                 self.g_repeat_arpeggio.hide()
+            if self.m_t.m_P.header.have_music_displayer:
+                self.g_music_displayer.show()
+            else:
+                self.g_music_displayer.hide()
             self.g_repeat.set_sensitive(False)
             self.g_repeat_arpeggio.set_sensitive(False)
             self.g_play_answer.set_sensitive(False)
