@@ -18,7 +18,7 @@
 __exercise_data__ = {
     'exercise_name': 'twelve-tone',
     'menu_path': '%s/%s' % (_("_Misc exercises"), _("Sing _twelvetone")),
-    'icon': 'graphics/twelvetone24.png',
+    'stock-icon': 'solfege-twelve-tone',
     'toolbar': 7,
 }
 import exercise_setup
