@@ -19,7 +19,9 @@ from instrumentselector import InstrumentSelector, InstrumentConfigurator
 from notenamespinbutton import NotenameRangeController, \
                                nNotenameRangeController, \
                                NotenameSpinButton
-from specialwidgets import QuestionNameButtonTable, QuestionNameCheckButtonTable, HarmonicProgressionLabel
+from specialwidgets import QuestionNameButtonTable, \
+    QuestionNameCheckButtonTable, HarmonicProgressionLabel, \
+    RandomTransposeDialog
 from multipleintervalconfigwidget import MultipleIntervalConfigWidget, \
                                           IntervalCheckBox
 from selectlessonfilewidget import SelectLessonfileWidget
